parser

package
v0.0.0-...-17041c3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 10, 2021 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ParseRange

func ParseRange(s string) (min int64, max int64, err error)

ParseRange parses string from format "${min}-${max}" as min, max values where min, max are integers return error in case of wrong format or when min>max.

func ParseStep

func ParseStep(s string, min, max int64) ([]int64, error)

ParseStep returnes values for min-max range with step parsed from s in format "*/${step}" where step is an integer return error in case of wrong format or step bigger than range.

Types

This section is empty.

Jump to