Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ExistenceMap ¶
type ExistenceMap struct {
// contains filtered or unexported fields
}
ExistenceMap provides mechanisms for handling ints exisntace in sets.
func New ¶
func New(min, max int64) (*ExistenceMap, error)
New creates existenceMap with min-max range handling returns error in case of max<min.
func (*ExistenceMap) AllExists ¶
func (e *ExistenceMap) AllExists()
func (*ExistenceMap) ApplyNumber ¶
func (e *ExistenceMap) ApplyNumber(v int64) error
ApplyNumber marks value as existing returns error if value is out of bound.
func (*ExistenceMap) ApplyRange ¶
func (e *ExistenceMap) ApplyRange(min, max int64) error
ApplyRange marks all values from slice as existing returns error if any value is out of bound.
func (*ExistenceMap) ApplySlice ¶
func (e *ExistenceMap) ApplySlice(vals []int64) error
ApplySlice marks all values from slice as existing returns error if any value is out of bound.
func (ExistenceMap) ToInt64Slice ¶
func (e ExistenceMap) ToInt64Slice() []int64
ToInt64Slice provides slice of int64 based on the bool map and min value offset.
Click to show internal directories.
Click to hide internal directories.